==> firekeeper-0.2.10.tar.gz: firekeeper-0.2.10/chrome/content/firekeeper.js <==
/*$Id: firekeeper.js,v 1.17 2007/02/15 16:00:42 jwrobel Exp $*/
/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

/*
  Observe state of Firekeeper (enable/disable)
 */
var enabledObserver =
{
	init: function()
	{
		var prefService = Components
		.classes["@mozilla.org/preferences-service;1"]
		.getService(Components.interfaces.nsIPrefService);
		
		this.branch = prefService.getBranch("extensions.firekeeper.");
		this.branch.QueryInterface(Components.interfaces
					   .nsIPrefBranch2);
		this.branch.addObserver("enabled", this, true);
	},

	unregister: function()
	{
		if(!this.branch) {
			return;
		}
		this.branch.removeObserver("enabled", this);
	},

	setStatus: function()
	{
		var menuitem = document.getElementById('enable-menuitem');
		var statusbar = document.getElementById('firekeeper-status');		
		var enable = this.branch.getBoolPref("enabled");
		
		if (enable){
			menuitem.setAttribute('label', 'Disable Firekeeper');
			statusbar.setAttribute('status', 'enabled');
		}
		else{
			menuitem.setAttribute('label', 'Enable Firekeeper');
			statusbar.setAttribute('status', 'disabled');
		}		
	},
	
	observe: function(aSubject, aTopic, aData)
	{
		if(aTopic != "nsPref:changed"){
			return;
		}
		
		this.setStatus();		
	},

	QueryInterface: function(iid){
		if ( iid.equals(Components.interfaces.nsIObserver) ||
		     iid.equals(Components.interfaces
				.nsISupportsWeakReference)         ||
		     iid.equals(Components.interfaces.nsISupports))
		return this;
		throw Components.results.NS_NOINTERFACE;
	}	
}

function firekeeperInit(event)
{	
	getServices();
	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService);
	prefs = prefs.getBranch("extensions.firekeeper.");
	var enabled = prefs.getBoolPref("enabled");
	
	firekeeper.enable(enabled);
	
	enabledObserver.init();
	enabledObserver.setStatus();
		
	
	/*
	debug.init();
	firekeeperState = FirekeeperState("loading");

	var FIREKEEPER_CONTRACTID = "@firekeeper.mozdev.org/firekeeper"
	firekeeper  = Components.classes[FIREKEEPER_CONTRACTID];
	
	if (firekeeper == null){
		var errMsg = "Firekeeper load failed: " + 
			"component " + FIREKEEPER_CONTRACTID + 
			" not registered";
		firekeeperState.changeState("error", errMsg);
		throw(errMsg);
	}

	firekeeper = firekeeper.getService(Components.interfaces.fkIFirekeeper);
	if (firekeeper == null){
		var errMsg = "Firekeeper load failed: " +
			"can't obtain fkIFirekeeper interface";
		firekeeperState.changeState("error", errMsg);
		throw(errMsg);
	}
	try{
		debug.msg("what");
		fkRulesLoader = new RulesLoader();
		fkRulesLoader.init();
		fkJudge.init();
		firekeeper.setJudge(fkJudge);
		firekeeperState.changeState("loaded", "Firekeeper is enabled");
		var prefs = Components.classes["@mozilla.org/preferences-service;1"].
			getService(Components.interfaces.nsIPrefService);		
			prefs = prefs.getBranch("extensions.firekeeper.");
		var enabled = prefs.getBoolPref("enabled");
		debug.msg("setting " + enabled);
		firekeeper.enable(enabled);
		
	}catch(e){
		errMsg = "Firekeeper initialization failed " + e;
		firekeeperState.
			changeState("error", errMsg);
		throw(errMsg);
	}
	*/
}


function openConfigWindow()
{
	//window.openDialog('chrome://firekeeper/content/config.xul', 'preferences', 
	//	  'chrome,resizable,centerscreen,dialog=no');
	window.openDialog('chrome://firekeeper/content/config.xul', '_blank', 
		    'chrome,modal=yes,resizable,centerscreen');
	
}

function changeEnable()
{	
	var statusbar = document.getElementById('firekeeper-status');
	var status = statusbar.getAttribute('status');
	
	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService);		
	prefs = prefs.getBranch("extensions.firekeeper.");

	if (status == 'enabled'){
		firekeeper.enable(false);
		prefs.setBoolPref("enabled", false);
	}
	else if (status == 'disabled') {
		firekeeper.enable(true);
		prefs.setBoolPref("enabled", true);
	}
	
}

window.addEventListener('load', firekeeperInit, false);

==> firekeeper-0.2.14.tar.gz: firekeeper-0.2.14/chrome/content/firekeeper.js <==
/*$Id: firekeeper.js,v 1.18 2007/09/09 10:44:26 jwrobel Exp $*/
/* ***** BEGIN LICENSE BLOCK *****
 *  This file is part of Firekeeper.
 *
 *  Copyright (C) 2006,2007 Jan Wrobel <wrobel@blues.ath.cx>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 * ***** END LICENSE BLOCK ***** */

/*
  Observe state of Firekeeper (enable/disable)
 */
var enabledObserver =
{
	init: function()
	{
		var prefService = Components
		.classes["@mozilla.org/preferences-service;1"]
		.getService(Components.interfaces.nsIPrefService);
		
		this.branch = prefService.getBranch("extensions.firekeeper.");
		this.branch.QueryInterface(Components.interfaces
					   .nsIPrefBranch2);
		this.branch.addObserver("enabled", this, true);
		this.branch.addObserver("toolbar_icon", this, true);
	},

	unregister: function()
	{
		if(!this.branch) {
			return;
		}
		this.branch.removeObserver("enabled", this);
		this.branch.removeObserver("toolbar_icon", this);
	},

	setStatus: function()
	{
		var menuitem = document.getElementById('enable-menuitem');
		var statusbar = document.getElementById('firekeeper-status');		
		var enable = this.branch.getBoolPref("enabled");
		
		if (enable){
			menuitem.setAttribute('label', 'Disable Firekeeper');
			statusbar.setAttribute('status', 'enabled');
		}
		else{
			menuitem.setAttribute('label', 'Enable Firekeeper');
			statusbar.setAttribute('status', 'disabled');
		}		
	},
	
	showIcon: function()
	{
		var visible = this.branch.getBoolPref("toolbar_icon");

		
		if (visible){
			showElement('firekeeper-status');
		}else{
			hideElement('firekeeper-status');
		}
	},
	
	observe: function(aSubject, aTopic, aData)
	{
		if(aTopic != "nsPref:changed"){
			return;
		}

		this.setStatus();
		this.showIcon();
	},

	QueryInterface: function(iid){
		if ( iid.equals(Components.interfaces.nsIObserver) ||
		     iid.equals(Components.interfaces
				.nsISupportsWeakReference)         ||
		     iid.equals(Components.interfaces.nsISupports))
		return this;
		throw Components.results.NS_NOINTERFACE;
	}	
}

function firekeeperInit(event)
{	
	getServices();
	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService);
	prefs = prefs.getBranch("extensions.firekeeper.");
	var enabled = prefs.getBoolPref("enabled");
	
	firekeeper.enable(enabled);
	
	enabledObserver.init();
	enabledObserver.setStatus();	
	enabledObserver.showIcon();
}


function openConfigWindow()
{
	//window.openDialog('chrome://firekeeper/content/config.xul', 'preferences', 
	//	  'chrome,resizable,centerscreen,dialog=no');
	window.openDialog('chrome://firekeeper/content/config.xul', '_blank', 
		    'chrome,modal=yes,resizable,centerscreen');
	
}

function changeEnable()
{	
	var statusbar = document.getElementById('firekeeper-status');
	var status = statusbar.getAttribute('status');
	
	var prefs = Components.classes["@mozilla.org/preferences-service;1"].
		getService(Components.interfaces.nsIPrefService);		
	prefs = prefs.getBranch("extensions.firekeeper.");

	if (status == 'enabled'){
		firekeeper.enable(false);
		prefs.setBoolPref("enabled", false);
	}
	else if (status == 'disabled') {
		firekeeper.enable(true);
		prefs.setBoolPref("enabled", true);
	}
	
}

window.addEventListener('load', firekeeperInit, false);
